@@ -66,7 +66,7 @@ static int
 help_cb (GtkWidget   *w,
 	 DialogData  *data)
 {
-	show_help_dialog (GTK_WINDOW (data->dialog), "file-roller-view-archive-properties");
+	show_help_dialog (GTK_WINDOW (data->dialog), "archive-properties");
 	return TRUE;
 }
 
